@@ -29,9 +29,7 @@
 #include <linux/slab.h>
 #include <linux/init.h>
 #include <linux/version.h>
-#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,5,7))
 #include <linux/locks.h>
-#endif
 #include <linux/list.h>
 #include "cifsfs.h"
 #include "cifspdu.h"
@@ -57,7 +55,6 @@ extern int cifs_umount(struct super_block *, struct cifs_sb_info *);
 void cifs_proc_init(void);
 void cifs_proc_clean(void);
 
-#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,5,0))
 struct super_block *cifs_read_super(struct super_block *sb,
 				    void *data, int silent)
 {
@@ -108,56 +105,6 @@ struct super_block *cifs_read_super(struct super_block *sb,
 	sb->s_dev = 0;
 	return 0;
 }
-#else
-static int cifs_read_super(struct super_block *sb, void *data, int silent)
-{
-	struct inode *inode;
-	struct cifs_sb_info *cifs_sb;
-	int rc = 0;
-
-	/* dump_mem(" cifs_fs_type ", &cifs_fs_type, sizeof(cifs_fs_type)); */
-	cifs_sb = (struct cifs_sb_info *) &sb->u;
-	cifs_sb->local_nls = load_nls_default();	/* needed for ASCII cp to Unicode converts */
-	rc = cifs_mount(sb, cifs_sb, data);
-
-	if (rc) {
-		if (!silent)
-			cERROR(1,
-			       ("cifs_mount failed w/return code = %d\n",
-				rc));
-		goto out_mount_failed;
-	}
-
-	sb->s_magic = CIFS_MAGIC_NUMBER;
-	sb->s_op = &cifs_super_ops;
-	sb->s_blocksize = CIFS_MAX_MSGSIZE;	/* BB check SMBSessSetup negotiated size */
-	sb->s_blocksize_bits = 10;	/* 2**10 = CIFS_MAX_MSGSIZE */
-	inode = iget(sb, ROOT_I);
-
-	if (!inode)
-		goto out_no_root;
-
-	sb->s_root = d_alloc_root(inode);
-
-	if (!sb->s_root)
-		goto out_no_root;
-
-	return 0;
-
-      out_no_root:
-	cEVENT(1, ("cifs_read_super: get root inode failed\n"));
-	if (inode)
-		iput(inode);
-
-/*	rc = cifs_umount(sb);  BB is CIFS unmount routine needed? */
-	if (rc) {
-		cERROR(1,
-		       ("cifs_umount failed with return code %d\n", rc));
-	}
-      out_mount_failed:
-	return -EINVAL;
-}
-#endif
 
 void cifs_put_super(struct super_block *sb)
 {
@@ -228,7 +175,6 @@ struct super_operations cifs_super_ops = {
    remount_fs:   cifs_remount_fs, *//* TBD */
 };
 
-#if (LINUX_VERSION_CODE < KERNEL_VERSION(2,5,0))
 static DECLARE_FSTYPE(cifs_fs_type, "cifs", cifs_read_super,
 		      0 /* BUGBUG FS_ flags go here */ );
 struct inode_operations cifs_dir_inode_ops = {	/* divide the following into file vs. dir inode operations */
@@ -250,41 +196,6 @@ struct inode_operations cifs_file_inode_ops = {
 	rename:cifs_rename,
 };
 
-#else
-static struct super_block *cifs_get_sb(struct file_system_type *fs_type,
-				       int flags, char *dev_name,
-				       void *data)
-{
-	cFYI(1, ("\nDevname: %s flags: %d ", dev_name, flags));
-	return get_sb_nodev(fs_type, flags, data, cifs_read_super);
-}
-
-static struct file_system_type cifs_fs_type = {
-	owner:THIS_MODULE,
-	name:"cifs",
-	get_sb:cifs_get_sb,
-};
-struct inode_operations cifs_dir_inode_ops = {	/* divide the following into file vs. dir inode operations */
-	create:cifs_create,
-	lookup:cifs_lookup,
-	unlink:cifs_unlink,
-	link:cifs_hardlink,
-	mkdir:cifs_mkdir,
-	rmdir:cifs_rmdir,
-	rename:cifs_rename,
-/*	revalidate:cifs_revalidate,   */
-	setattr:cifs_setattr,
-	symlink:cifs_symlink,
-};
-
-struct inode_operations cifs_file_inode_ops = {
-/*	revalidate:cifs_revalidate, */
-	setattr:cifs_setattr,
-	rename:cifs_rename,
-};
-#endif
-
-
 struct inode_operations cifs_symlink_inode_ops = {
 	readlink:cifs_readlink,
 	follow_link:cifs_follow_link,
