@@ -81,11 +81,11 @@ enum statusEnum {
 };
 
 enum securityEnum {
-	NTLM = 0,  /* Legacy NTLM012 auth with NTLM hash */
-	NTLMv2,    /* Legacy NTLM auth with NTLMv2 hash */
-	RawNTLMSSP,   /* NTLMSSP without SPNEGO */
-    NTLMSSP,  /* NTLMSSP via SPNEGO */
-	Kerberos  /* Kerberos via SPNEGO */
+	NTLM = 0,		/* Legacy NTLM012 auth with NTLM hash */
+	NTLMv2,			/* Legacy NTLM auth with NTLMv2 hash */
+	RawNTLMSSP,		/* NTLMSSP without SPNEGO */
+	NTLMSSP,		/* NTLMSSP via SPNEGO */
+	Kerberos		/* Kerberos via SPNEGO */
 };
 
 
@@ -115,7 +115,7 @@ struct TCP_Server_Info {
 	enum statusEnum tcpStatus;	/* what we think the status is */
 	struct semaphore tcpSem;
 	struct task_struct *tsk;
-    char server_GUID[16];
+	char server_GUID[16];
 };
 
 /*
@@ -144,7 +144,7 @@ struct cifsSesInfo {
 	enum statusEnum status;
 	int dialectIndex;	/* the negotiated dialect index */
 	char secMode;
-    enum securityEnum secType;
+	enum securityEnum secType;
 	unsigned int maxReq;	/* Clients should submit no more */
 	/* than maxReq distinct unanswered SMBs to the server when using  */
 	/* multiplexed reads or writes */
@@ -216,7 +216,8 @@ struct cifsFileInfo {
  */
 
 struct cifsInodeInfo {
-	struct cifsLockInfo *lockList;	/* BB replace with list and atomicize */
+	struct list_head lockList;
+	/* BB add in list for dirty pages */
 	__u32 cifsAttrs;	/* e.g. DOS archive bit, sparse, compressed, system etc. */
 	atomic_t inUse;		/* num concurrent users (local openers cifs) of file */
 	unsigned long time;	/* jiffies of last update/check of inode */
