@@ -47,7 +47,8 @@ extern int SendReceive(const unsigned int /* xid */ , struct cifsSesInfo *,
 extern int checkSMBhdr(struct smb_hdr *smb, __u16 mid);
 extern int checkSMB(struct smb_hdr *smb, __u16 mid, int length);
 extern int smbCalcSize(struct smb_hdr *ptr);
-extern int decode_negTokenInit(unsigned char *security_blob, int length, enum securityEnum * secType);
+extern int decode_negTokenInit(unsigned char *security_blob, int length,
+			       enum securityEnum *secType);
 extern int map_smb_to_linux_error(struct smb_hdr *smb);
 extern void header_assemble(struct smb_hdr *, char /* command */ ,
 			    const struct cifsTconInfo *, int
@@ -71,22 +72,28 @@ extern int cifs_get_inode_info_unix(struct inode **pinode,
 extern int CIFSSMBNegotiate(unsigned int xid, struct cifsSesInfo *ses,
 			    char cryptokey[CIFS_CRYPTO_KEY_SIZE]);
 extern int CIFSSessSetup(unsigned int xid, struct cifsSesInfo *ses,
-			    char *user, char *domain,
-			    char * session_key, char * ntlm_session_key,
-			    const struct nls_table *);
+			 char *user, char *domain,
+			 char *session_key, char *ntlm_session_key,
+			 const struct nls_table *);
 extern int CIFSSpnegoSessSetup(unsigned int xid, struct cifsSesInfo *ses,
-			      char *user, char *domain,
-			      char *SecurityBlob,
-			      int SecurityBlobLength,
-			      const struct nls_table *);
-extern int CIFSNTLMSSPNegotiateSessSetup(unsigned int xid, struct cifsSesInfo *ses,
-			      char *domain, char * ntlm_session_key, const struct nls_table *);
-extern int CIFSNTLMSSPAuthSessSetup(unsigned int xid, struct cifsSesInfo *ses,
-			      char * user, char *domain, char * ntlm_session_key, char * lanman_session_key, const struct nls_table *);
+			       char *user, char *domain,
+			       char *SecurityBlob,
+			       int SecurityBlobLength,
+			       const struct nls_table *);
+extern int CIFSNTLMSSPNegotiateSessSetup(unsigned int xid,
+					 struct cifsSesInfo *ses,
+					 char *domain,
+					 char *ntlm_session_key,
+					 const struct nls_table *);
+extern int CIFSNTLMSSPAuthSessSetup(unsigned int xid,
+				    struct cifsSesInfo *ses, char *user,
+				    char *domain, char *ntlm_session_key,
+				    char *lanman_session_key,
+				    const struct nls_table *);
 
 extern int CIFSTCon(unsigned int xid, struct cifsSesInfo *ses,
-		       const char *tree, struct cifsTconInfo *tcon,
-		       const struct nls_table *);
+		    const char *tree, struct cifsTconInfo *tcon,
+		    const struct nls_table *);
 
 extern int CIFSFindFirst(const int xid, const struct cifsTconInfo *tcon,
 			 const char *searchName,
