@@ -49,12 +49,12 @@ int smb_init(int smb_command, int wct, const struct cifsTconInfo *tcon,
 
 	*request_buf = buf_get();
 	if (request_buf == 0) {
-		return ENOMEM;
+		return -ENOMEM;
 	}
 	*response_buf = buf_get();
 	if (response_buf == 0) {
 		buf_release(request_buf);
-		return ENOMEM;
+		return -ENOMEM;
 	}
 
 	header_assemble((struct smb_hdr *) *request_buf, smb_command, tcon,
@@ -100,7 +100,7 @@ int CIFSSMBNegotiate(unsigned int xid, struct cifsSesInfo *ses,
 		cFYI(1, ("\nMax buf = %d ", ses->maxBuf));
 		GETU32(ses->sessid) = le32_to_cpu(pSMBr->SessionKey);
 		ses->capabilities = le32_to_cpu(pSMBr->Capabilities);
-		ses->timeZone = le16_to_cpu(pSMBr->ServerTimeZone);  /* BB with UTC do we ever need to be using srvr timezone? */
+		ses->timeZone = le16_to_cpu(pSMBr->ServerTimeZone);	/* BB with UTC do we ever need to be using srvr timezone? */
 		if (pSMBr->EncryptionKeyLength == CIFS_CRYPTO_KEY_SIZE) {
 			memcpy(cryptokey, pSMBr->u.EncryptionKey,
 			       CIFS_CRYPTO_KEY_SIZE);
@@ -112,26 +112,36 @@ int CIFSSMBNegotiate(unsigned int xid, struct cifsSesInfo *ses,
 
 		/* BB might be helpful to save off the domain of server here */
 
-		if (pSMBr->hdr.Flags2 & SMBFLG2_EXT_SEC) {		
+		if (pSMBr->hdr.Flags2 & SMBFLG2_EXT_SEC) {
 			if (pSMBr->ByteCount < 16)
 				rc = -EIO;
-            else if (pSMBr->ByteCount == 16) {
-                ses->secType = RawNTLMSSP;     
-                if (ses->server->socketUseCount.counter > 1) { 
-                    if( memcmp(ses->server->server_GUID,pSMBr->u.extended_response.GUID,16) != 0) {                    
-                        cFYI(1,("UID of server does not match that of previous connection to same ip address"));
-                        memcpy(ses->server->server_GUID, pSMBr->u.extended_response.GUID,16);
-                    }
-                }
-                else
-                    memcpy(ses->server->server_GUID, pSMBr->u.extended_response.GUID,16);
-            }
-			else {
+			else if (pSMBr->ByteCount == 16) {
+				ses->secType = RawNTLMSSP;
+				if (ses->server->socketUseCount.counter >
+				    1) {
+					if (memcmp
+					    (ses->server->server_GUID,
+					     pSMBr->u.extended_response.
+					     GUID, 16) != 0) {
+						cFYI(1,
+						     ("UID of server does not match that of previous connection to same ip address"));
+						memcpy(ses->server->
+						       server_GUID,
+						       pSMBr->u.
+						       extended_response.
+						       GUID, 16);
+					}
+				} else
+					memcpy(ses->server->server_GUID,
+					       pSMBr->u.extended_response.
+					       GUID, 16);
+			} else {
 				rc = decode_negTokenInit(pSMBr->u.
 							 extended_response.
 							 SecurityBlob,
-							 pSMBr->ByteCount - 16, 
-                             &ses->secType);
+							 pSMBr->ByteCount -
+							 16,
+							 &ses->secType);
 			}
 
 		} else
@@ -446,7 +456,7 @@ int CIFSSMBOpen(const int xid, const struct cifsTconInfo *tcon,
 		*netfid = pSMBr->Fid;	/* cifs fid stays in le */
 		/* Do we care about the CreateAction in any cases? */
 
-        /* BB add code to update inode with file sizes from create response */
+		/* BB add code to update inode with file sizes from create response */
 	}
 	if (pSMB)
 		buf_release(pSMB);
@@ -476,8 +486,10 @@ int CIFSSMBRead(const int xid, const struct cifsTconInfo *tcon,
 	pSMB->OffsetLow = cpu_to_le32(lseek & 0xFFFFFFFF);
 	pSMB->OffsetHigh = cpu_to_le32(lseek >> 32);
 	pSMB->Remaining = 0;
-	pSMB->MaxCount = cpu_to_le16( min(count,
-		  (tcon->ses->maxBuf - MAX_CIFS_HDR_SIZE) & 0xFFFFFF00));
+	pSMB->MaxCount = cpu_to_le16(min(count,
+					 (tcon->ses->maxBuf -
+					  MAX_CIFS_HDR_SIZE) &
+					 0xFFFFFF00));
 	pSMB->MaxCountHigh = 0;
 	pSMB->ByteCount = 0;	/* no need to do le conversion since it is 0 */
 
@@ -487,7 +499,7 @@ int CIFSSMBRead(const int xid, const struct cifsTconInfo *tcon,
 		cERROR(1, ("\nSend error in read = %d\n", rc));
 		*nbytes = 0;
 	} else {
-        pSMBr->DataLength = le16_to_cpu(pSMBr->DataLength);
+		pSMBr->DataLength = le16_to_cpu(pSMBr->DataLength);
 		*nbytes = pSMBr->DataLength;
 		/* BB check that DataLength would not go beyond end of SMB BB */
 /* if(pSMBr->DataOffset < pSMBr->ByteCount + sizeof(READ_RSP) - 1 *//* BB fix this length check */
@@ -498,8 +510,8 @@ int CIFSSMBRead(const int xid, const struct cifsTconInfo *tcon,
 		} else {
 			pReadData =
 			    (char *) (&pSMBr->hdr.Protocol) +
-			    le16_to_cpu(pSMBr->DataOffset);			
-            copy_to_user(buf,pReadData,pSMBr->DataLength);
+			    le16_to_cpu(pSMBr->DataOffset);
+			copy_to_user(buf, pReadData, pSMBr->DataLength);
 		}
 	}
 
@@ -533,16 +545,17 @@ int CIFSSMBWrite(const int xid, const struct cifsTconInfo *tcon,
 	pSMB->OffsetHigh = cpu_to_le32(offset >> 32);
 	pSMB->Remaining = 0;
 	if (count > ((tcon->ses->maxBuf - MAX_CIFS_HDR_SIZE) & 0xFFFFFF00))
-		pSMB->DataLengthLow = 
-            (tcon->ses->maxBuf - MAX_CIFS_HDR_SIZE) & 0xFFFFFF00;
+		pSMB->DataLengthLow =
+		    (tcon->ses->maxBuf - MAX_CIFS_HDR_SIZE) & 0xFFFFFF00;
 	else
 		pSMB->DataLengthLow = count;
 	pSMB->DataLengthHigh = 0;
-	pSMB->DataOffset = cpu_to_le16((int) &(pSMB->Data) - (int) pSMB->hdr.Protocol);
+	pSMB->DataOffset =
+	    cpu_to_le16((int) &(pSMB->Data) - (int) pSMB->hdr.Protocol);
 	copy_from_user(pSMB->Data, buf, pSMB->DataLengthLow);
 
 	pSMB->ByteCount += pSMB->DataLengthLow + 1 /* pad */ ;
-    pSMB->DataLengthLow = cpu_to_le16(pSMB->DataLengthLow);
+	pSMB->DataLengthLow = cpu_to_le16(pSMB->DataLengthLow);
 	pSMB->hdr.smb_buf_length += pSMB->ByteCount;
 	pSMB->ByteCount = cpu_to_le16(pSMB->ByteCount);
 
@@ -658,7 +671,8 @@ int CIFSSMBRename(const int xid, const struct cifsTconInfo *tcon,
 
 	pSMB->BufferFormat = 0x04;
 	pSMB->SearchAttributes =
-	    cpu_to_le16(ATTR_READONLY | ATTR_HIDDEN | ATTR_SYSTEM | ATTR_DIRECTORY);
+	    cpu_to_le16(ATTR_READONLY | ATTR_HIDDEN | ATTR_SYSTEM |
+			ATTR_DIRECTORY);
 
 	if (pSMB->hdr.Flags2 & SMBFLG2_UNICODE) {
 		name_len =
@@ -750,8 +764,7 @@ int CIFSUnixCreateSymLink(const int xid, const struct cifsTconInfo *tcon,
 	pSMB->Reserved2 = 0;
 	pSMB->ParameterOffset =
 	    (int) &(pSMB->InformationLevel) - (int) pSMB->hdr.Protocol;
-	pSMB->DataOffset =
-	    pSMB->ParameterOffset + pSMB->ParameterCount;
+	pSMB->DataOffset = pSMB->ParameterOffset + pSMB->ParameterCount;
 
 	data_offset = (char *) (&pSMB->hdr.Protocol) + pSMB->DataOffset;
 	if (pSMB->hdr.Flags2 & SMBFLG2_UNICODE) {
@@ -775,12 +788,12 @@ int CIFSUnixCreateSymLink(const int xid, const struct cifsTconInfo *tcon,
 	pSMB->SubCommand = cpu_to_le16(TRANS2_SET_PATH_INFORMATION);
 	pSMB->ByteCount =
 	    3 /* pad */  + pSMB->ParameterCount + pSMB->DataCount;
-    pSMB->DataCount = cpu_to_le16(pSMB->DataCount);
-    pSMB->ParameterCount = cpu_to_le16(pSMB->ParameterCount);
-    pSMB->TotalDataCount = pSMB->DataCount;
-    pSMB->TotalParameterCount = pSMB->ParameterCount;
-    pSMB->ParameterOffset = cpu_to_le16(pSMB->ParameterOffset);
-    pSMB->DataOffset = cpu_to_le16(pSMB->DataOffset);
+	pSMB->DataCount = cpu_to_le16(pSMB->DataCount);
+	pSMB->ParameterCount = cpu_to_le16(pSMB->ParameterCount);
+	pSMB->TotalDataCount = pSMB->DataCount;
+	pSMB->TotalParameterCount = pSMB->ParameterCount;
+	pSMB->ParameterOffset = cpu_to_le16(pSMB->ParameterOffset);
+	pSMB->DataOffset = cpu_to_le16(pSMB->DataOffset);
 	pSMB->InformationLevel = cpu_to_le16(SMB_SET_FILE_UNIX_LINK);
 	pSMB->Reserved4 = 0;
 	pSMB->hdr.smb_buf_length += pSMB->ByteCount;
@@ -838,9 +851,9 @@ int CIFSUnixCreateHardLink(const int xid, const struct cifsTconInfo *tcon,
 	pSMB->Flags = 0;
 	pSMB->Timeout = 0;
 	pSMB->Reserved2 = 0;
-	pSMB->ParameterOffset = (int) &(pSMB->InformationLevel) - (int) pSMB->hdr.Protocol;
-	pSMB->DataOffset =
-	    pSMB->ParameterOffset + pSMB->TotalParameterCount;
+	pSMB->ParameterOffset =
+	    (int) &(pSMB->InformationLevel) - (int) pSMB->hdr.Protocol;
+	pSMB->DataOffset = pSMB->ParameterOffset + pSMB->ParameterCount;
 
 	data_offset = (char *) (&pSMB->hdr.Protocol) + pSMB->DataOffset;
 	if (pSMB->hdr.Flags2 & SMBFLG2_UNICODE) {
@@ -906,7 +919,9 @@ int CIFSCreateHardLink(const int xid, const struct cifsTconInfo *tcon,
 	if (rc)
 		return rc;
 
-	pSMB->SearchAttributes = cpu_to_le16(ATTR_READONLY | ATTR_HIDDEN | ATTR_SYSTEM | ATTR_DIRECTORY);
+	pSMB->SearchAttributes =
+	    cpu_to_le16(ATTR_READONLY | ATTR_HIDDEN | ATTR_SYSTEM |
+			ATTR_DIRECTORY);
 	pSMB->Flags = cpu_to_le16(CREATE_HARD_LINK);
 	pSMB->ClusterCount = 0;
 
@@ -995,7 +1010,8 @@ int CIFSSMBUnixQuerySymLink(const int xid, const struct cifsTconInfo *tcon,
 		strncpy(pSMB->FileName, searchName, name_len);
 	}
 
-	pSMB->TotalParameterCount = 2 /* level */  + 4 /* rsrvd */ + name_len /* incl null */ ;
+	pSMB->TotalParameterCount =
+	    2 /* level */  + 4 /* rsrvd */  + name_len /* incl null */ ;
 	pSMB->TotalDataCount = 0;
 	pSMB->MaxParameterCount = cpu_to_le16(2);
 	pSMB->MaxDataCount = cpu_to_le16(4000);	/* BB find exact max SMB PDU from sess structure BB */
@@ -1004,7 +1020,9 @@ int CIFSSMBUnixQuerySymLink(const int xid, const struct cifsTconInfo *tcon,
 	pSMB->Flags = 0;
 	pSMB->Timeout = 0;
 	pSMB->Reserved2 = 0;
-	pSMB->ParameterOffset = cpu_to_le16((int) &(pSMB->InformationLevel) - (int) pSMB->hdr.Protocol);
+	pSMB->ParameterOffset =
+	    cpu_to_le16((int) &(pSMB->InformationLevel) -
+			(int) pSMB->hdr.Protocol);
 	pSMB->DataCount = 0;
 	pSMB->DataOffset = 0;
 	pSMB->SetupCount = 1;
@@ -1023,19 +1041,38 @@ int CIFSSMBUnixQuerySymLink(const int xid, const struct cifsTconInfo *tcon,
 	if (rc) {
 		cFYI(1, ("\nSend error in QuerySymLinkInfo = %d\n", rc));
 	} else {		/* decode response */
-        pSMBr->DataOffset = le16_to_cpu(pSMBr->DataOffset);
-        pSMBr->DataCount = le16_to_cpu(pSMBr->DataCount);
+		pSMBr->DataOffset = le16_to_cpu(pSMBr->DataOffset);
+		pSMBr->DataCount = le16_to_cpu(pSMBr->DataCount);
 		if ((pSMBr->ByteCount < 2) || (pSMBr->DataOffset > 512))	/* BB also check enough total bytes returned */
-			rc = EIO;	/* bad smb */
+			rc = -EIO;	/* bad smb */
 		else {
-            if(pSMBr->hdr.Flags2 & SMBFLG2_UNICODE) {
-                name_len = UniStrnlen((UniChar *) ((char *) &pSMBr->hdr.Protocol + pSMBr->DataOffset), min(buflen,(int)pSMBr->DataCount)/2);
-                cifs_strfromUCS_le(symlinkinfo,(UniChar *)((char *) &pSMBr->hdr.Protocol + pSMBr->DataOffset),name_len,nls_codepage);
-            }
-            else{            
-			    strncpy(symlinkinfo, (char *) &pSMBr->hdr.Protocol + pSMBr->DataOffset, min(buflen, (int)pSMBr->DataCount));
-            }
-            symlinkinfo[buflen] = 0; /* just in case so the calling code does not go off the end of the buffer */
+			if (pSMBr->hdr.Flags2 & SMBFLG2_UNICODE) {
+				name_len =
+				    UniStrnlen((UniChar *) ((char *)
+							    &pSMBr->hdr.
+							    Protocol +
+							    pSMBr->
+							    DataOffset),
+					       min(buflen,
+						   (int) pSMBr->
+						   DataCount) / 2);
+				cifs_strfromUCS_le(symlinkinfo,
+						   (UniChar *) ((char *)
+								&pSMBr->
+								hdr.
+								Protocol +
+								pSMBr->
+								DataOffset),
+						   name_len, nls_codepage);
+			} else {
+				strncpy(symlinkinfo,
+					(char *) &pSMBr->hdr.Protocol +
+					pSMBr->DataOffset, min(buflen,
+							       (int)
+							       pSMBr->
+							       DataCount));
+			}
+			symlinkinfo[buflen] = 0;	/* just in case so the calling code does not go off the end of the buffer */
 		}
 	}
 	if (pSMB)
@@ -1090,15 +1127,15 @@ int CIFSSMBQPathInfo(const int xid, const struct cifsTconInfo *tcon,
 	pSMB->Flags = 0;
 	pSMB->Timeout = 0;
 	pSMB->Reserved2 = 0;
-	pSMB->ParameterOffset = cpu_to_le16(
-	    (int) &(pSMB->InformationLevel) - (int) pSMB->hdr.Protocol);
+	pSMB->ParameterOffset = cpu_to_le16((int) &(pSMB->InformationLevel)
+					    - (int) pSMB->hdr.Protocol);
 	pSMB->DataCount = 0;
 	pSMB->DataOffset = 0;
 	pSMB->SetupCount = 1;
 	pSMB->Reserved3 = 0;
 	pSMB->SubCommand = cpu_to_le16(TRANS2_QUERY_PATH_INFORMATION);
 	pSMB->ByteCount = pSMB->TotalParameterCount + 1 /* pad */ ;
-    pSMB->TotalParameterCount = cpu_to_le16(pSMB->TotalParameterCount);
+	pSMB->TotalParameterCount = cpu_to_le16(pSMB->TotalParameterCount);
 	pSMB->ParameterCount = pSMB->TotalParameterCount;
 	pSMB->InformationLevel = cpu_to_le16(SMB_QUERY_FILE_ALL_INFO);
 	pSMB->Reserved4 = 0;
@@ -1110,9 +1147,9 @@ int CIFSSMBQPathInfo(const int xid, const struct cifsTconInfo *tcon,
 	if (rc) {
 		cFYI(1, ("\nSend error in QPathInfo = %d\n", rc));
 	} else {		/* decode response */
-        pSMBr->DataOffset = le16_to_cpu(pSMBr->DataOffset);
+		pSMBr->DataOffset = le16_to_cpu(pSMBr->DataOffset);
 		if ((pSMBr->ByteCount < 40) || (pSMBr->DataOffset > 512))	/* BB also check enough total bytes returned */
-			rc = EIO;	/* bad smb */
+			rc = -EIO;	/* bad smb */
 		else {
 			memcpy((char *) pFindData,
 			       (char *) &pSMBr->hdr.Protocol +
@@ -1169,7 +1206,9 @@ int CIFSSMBUnixQPathInfo(const int xid, const struct cifsTconInfo *tcon,
 	pSMB->Flags = 0;
 	pSMB->Timeout = 0;
 	pSMB->Reserved2 = 0;
-	pSMB->ParameterOffset = cpu_to_le16((int) &(pSMB->InformationLevel) - (int) pSMB->hdr.Protocol);
+	pSMB->ParameterOffset =
+	    cpu_to_le16((int) &(pSMB->InformationLevel) -
+			(int) pSMB->hdr.Protocol);
 	pSMB->DataCount = 0;
 	pSMB->DataOffset = 0;
 	pSMB->SetupCount = 1;
@@ -1188,9 +1227,9 @@ int CIFSSMBUnixQPathInfo(const int xid, const struct cifsTconInfo *tcon,
 	if (rc) {
 		cFYI(1, ("\nSend error in QPathInfo = %d\n", rc));
 	} else {		/* decode response */
-        pSMBr->DataOffset = le16_to_cpu(pSMBr->DataOffset);
+		pSMBr->DataOffset = le16_to_cpu(pSMBr->DataOffset);
 		if ((pSMBr->ByteCount < 40) || (pSMBr->DataOffset > 512))	/* BB also check enough total bytes returned */
-			rc = EIO;	/* bad smb */
+			rc = -EIO;	/* bad smb */
 		else {
 			memcpy((char *) pFindData,
 			       (char *) &pSMBr->hdr.Protocol +
@@ -1246,18 +1285,22 @@ int CIFSFindSingle(const int xid, const struct cifsTconInfo *tcon,
 	pSMB->Flags = 0;
 	pSMB->Timeout = 0;
 	pSMB->Reserved2 = 0;
-	pSMB->ParameterOffset = cpu_to_le16((int) &pSMB->InformationLevel - (int) &pSMB->hdr.Protocol);
+	pSMB->ParameterOffset =
+	    cpu_to_le16((int) &pSMB->InformationLevel -
+			(int) &pSMB->hdr.Protocol);
 	pSMB->DataCount = 0;
 	pSMB->DataOffset = 0;
-	pSMB->SetupCount = 1; /* one byte, no need to le convert */
+	pSMB->SetupCount = 1;	/* one byte, no need to le convert */
 	pSMB->Reserved3 = 0;
 	pSMB->SubCommand = cpu_to_le16(TRANS2_FIND_FIRST);
 	pSMB->ByteCount = pSMB->TotalParameterCount + 1 /* pad */ ;
-    pSMB->TotalParameterCount = cpu_to_le16(pSMB->TotalDataCount);
+	pSMB->TotalParameterCount = cpu_to_le16(pSMB->TotalDataCount);
 	pSMB->ParameterCount = pSMB->TotalParameterCount;
-	pSMB->SearchAttributes = cpu_to_le16(ATTR_READONLY | ATTR_HIDDEN | ATTR_SYSTEM | ATTR_DIRECTORY);
+	pSMB->SearchAttributes =
+	    cpu_to_le16(ATTR_READONLY | ATTR_HIDDEN | ATTR_SYSTEM |
+			ATTR_DIRECTORY);
 	pSMB->SearchCount = cpu_to_le16(16);	/* BB increase */
-	pSMB->SearchFlags = cpu_to_le16(1);	
+	pSMB->SearchFlags = cpu_to_le16(1);
 	pSMB->InformationLevel = cpu_to_le16(SMB_FIND_FILE_DIRECTORY_INFO);
 	pSMB->SearchStorageType = 0;	/* BB what should we set this to? BB */
 	pSMB->hdr.smb_buf_length += pSMB->ByteCount;
@@ -1325,9 +1368,11 @@ int CIFSFindFirst(const int xid, const struct cifsTconInfo *tcon,
 	pSMB->Timeout = 0;
 	pSMB->Reserved2 = 0;
 	pSMB->ByteCount = pSMB->TotalParameterCount + 1 /* pad */ ;
-    pSMB->TotalParameterCount = cpu_to_le16(pSMB->TotalParameterCount);
+	pSMB->TotalParameterCount = cpu_to_le16(pSMB->TotalParameterCount);
 	pSMB->ParameterCount = pSMB->TotalParameterCount;
-	pSMB->ParameterOffset = cpu_to_le16((int) &pSMB->SearchAttributes - (int) &pSMB->hdr.Protocol);
+	pSMB->ParameterOffset =
+	    cpu_to_le16((int) &pSMB->SearchAttributes -
+			(int) &pSMB->hdr.Protocol);
 	pSMB->DataCount = 0;
 	pSMB->DataOffset = 0;
 	pSMB->SetupCount = 1;	/* one byte no need to make endian neutral */
@@ -1367,12 +1412,16 @@ int CIFSFindFirst(const int xid, const struct cifsTconInfo *tcon,
 		       (char *) &pSMBr->hdr.Protocol +
 		       le16_to_cpu(pSMBr->ParameterOffset),
 		       sizeof(T2_FFIRST_RSP_PARMS));
-        /* search handle can stay LE and EAoffset not needed so not converted */
-        findParms->EndofSearch = le16_to_cpu(findParms->EndofSearch);
-        findParms->LastNameOffset = le16_to_cpu(findParms->LastNameOffset);
-        findParms->SearchCount = le16_to_cpu(findParms->SearchCount);
+		/* search handle can stay LE and EAoffset not needed so not converted */
+		findParms->EndofSearch =
+		    le16_to_cpu(findParms->EndofSearch);
+		findParms->LastNameOffset =
+		    le16_to_cpu(findParms->LastNameOffset);
+		findParms->SearchCount =
+		    le16_to_cpu(findParms->SearchCount);
 		response_data =
-		    (char *) &pSMBr->hdr.Protocol + le16_to_cpu(pSMBr->DataOffset);
+		    (char *) &pSMBr->hdr.Protocol +
+		    le16_to_cpu(pSMBr->DataOffset);
 		memcpy(findData, response_data,
 		       le16_to_cpu(pSMBr->DataCount));
 	}
@@ -1404,22 +1453,26 @@ int CIFSFindNext(const int xid, const struct cifsTconInfo *tcon,
 	pSMB->TotalParameterCount = 14;	/* includes 2 bytes of null string, converted to LE below */
 	pSMB->TotalDataCount = 0;	/* no EAs */
 	pSMB->MaxParameterCount = cpu_to_le16(8);
-	pSMB->MaxDataCount = cpu_to_le16((tcon->ses->maxBuf - MAX_CIFS_HDR_SIZE) & 0xFFFFFF00);
+	pSMB->MaxDataCount =
+	    cpu_to_le16((tcon->ses->maxBuf -
+			 MAX_CIFS_HDR_SIZE) & 0xFFFFFF00);
 	pSMB->MaxSetupCount = 0;
 	pSMB->Reserved = 0;
 	pSMB->Flags = 0;
 	pSMB->Timeout = 0;
 	pSMB->Reserved2 = 0;
-	pSMB->ParameterOffset = cpu_to_le16((int) &pSMB->SearchHandle - (int) &pSMB->hdr.Protocol);
+	pSMB->ParameterOffset =
+	    cpu_to_le16((int) &pSMB->SearchHandle -
+			(int) &pSMB->hdr.Protocol);
 	pSMB->DataCount = 0;
 	pSMB->DataOffset = 0;
 	pSMB->SetupCount = 1;
 	pSMB->Reserved3 = 0;
 	pSMB->SubCommand = cpu_to_le16(TRANS2_FIND_NEXT);
 	pSMB->ByteCount = pSMB->TotalParameterCount + 1 /* pad */ ;
-	pSMB->TotalParameterCount = cpu_to_le16(pSMB->TotalParameterCount);   
+	pSMB->TotalParameterCount = cpu_to_le16(pSMB->TotalParameterCount);
 	pSMB->ParameterCount = pSMB->TotalParameterCount;
-	pSMB->SearchHandle = searchHandle;  /* always kept as le */
+	pSMB->SearchHandle = searchHandle;	/* always kept as le */
 	findParms->SearchCount = 0;	/* set to zero in case of error */
 	pSMB->SearchCount =
 	    cpu_to_le16(CIFS_MAX_MSGSIZE / sizeof(FILE_DIRECTORY_INFO));
@@ -1432,8 +1485,10 @@ int CIFSFindNext(const int xid, const struct cifsTconInfo *tcon,
 		    cpu_to_le16(SMB_FIND_FILE_DIRECTORY_INFO);
 		*pUnixFlag = FALSE;
 	}
-	pSMB->ResumeKey = resumeKey;  /* always kept as le */
-	pSMB->SearchFlags = cpu_to_le16(CIFS_SEARCH_CLOSE_AT_END | CIFS_SEARCH_CONTINUE_FROM_LAST);
+	pSMB->ResumeKey = resumeKey;	/* always kept as le */
+	pSMB->SearchFlags =
+	    cpu_to_le16(CIFS_SEARCH_CLOSE_AT_END |
+			CIFS_SEARCH_CONTINUE_FROM_LAST);
 	pSMB->hdr.smb_buf_length += pSMB->ByteCount;
 	pSMB->ByteCount = cpu_to_le16(pSMB->ByteCount);
 
@@ -1441,7 +1496,7 @@ int CIFSFindNext(const int xid, const struct cifsTconInfo *tcon,
 			 (struct smb_hdr *) pSMBr, &bytes_returned, 0);
 
 	if (rc) {
-		if (rc == EBADF)
+		if (rc == -EBADF)
 			rc = 0;	/* search probably was closed at end of search above */
 		else
 			cFYI(1, ("\nFindNext returned = %d\n", rc));
@@ -1453,13 +1508,19 @@ int CIFSFindNext(const int xid, const struct cifsTconInfo *tcon,
 			*pUnicodeFlag = FALSE;
 		memcpy(findParms,
 		       (char *) &pSMBr->hdr.Protocol +
-		       le16_to_cpu(pSMBr->ParameterOffset), sizeof(T2_FNEXT_RSP_PARMS));
-        findParms->EndofSearch = le16_to_cpu(findParms->EndofSearch);
-        findParms->LastNameOffset = le16_to_cpu(findParms->LastNameOffset);
-        findParms->SearchCount = le16_to_cpu(findParms->SearchCount);
+		       le16_to_cpu(pSMBr->ParameterOffset),
+		       sizeof(T2_FNEXT_RSP_PARMS));
+		findParms->EndofSearch =
+		    le16_to_cpu(findParms->EndofSearch);
+		findParms->LastNameOffset =
+		    le16_to_cpu(findParms->LastNameOffset);
+		findParms->SearchCount =
+		    le16_to_cpu(findParms->SearchCount);
 		response_data =
-		    (char *) &pSMBr->hdr.Protocol + le16_to_cpu(pSMBr->DataOffset);
-		memcpy(findData, response_data, le16_to_cpu(pSMBr->DataCount));
+		    (char *) &pSMBr->hdr.Protocol +
+		    le16_to_cpu(pSMBr->DataOffset);
+		memcpy(findData, response_data,
+		       le16_to_cpu(pSMBr->DataCount));
 	}
 	if (pSMB)
 		buf_release(pSMB);
@@ -1528,7 +1589,9 @@ int CIFSGetDFSRefer(const int xid, struct cifsSesInfo *ses,
 	pSMB->Flags = 0;
 	pSMB->Timeout = 0;
 	pSMB->Reserved2 = 0;
-	pSMB->ParameterOffset = cpu_to_le16((int) &(pSMB->MaxReferralLevel) - (int) pSMB->hdr.Protocol);
+	pSMB->ParameterOffset =
+	    cpu_to_le16((int) &(pSMB->MaxReferralLevel) -
+			(int) pSMB->hdr.Protocol);
 	pSMB->SetupCount = 1;
 	pSMB->Reserved3 = 0;
 	pSMB->SubCommand = cpu_to_le16(TRANS2_GET_DFS_REFERRAL);
@@ -1581,10 +1644,10 @@ int CIFSSMBQFSInfo(const int xid, const struct cifsTconInfo *tcon,
 	pSMB->Timeout = 0;
 	pSMB->Reserved2 = 0;
 	pSMB->ByteCount = pSMB->TotalParameterCount + 1 /* pad */ ;
-    pSMB->TotalParameterCount = cpu_to_le16(pSMB->TotalParameterCount);
+	pSMB->TotalParameterCount = cpu_to_le16(pSMB->TotalParameterCount);
 	pSMB->ParameterCount = pSMB->TotalParameterCount;
-	pSMB->ParameterOffset = cpu_to_le16(
-	    (int) &(pSMB->InformationLevel) - (int) pSMB->hdr.Protocol);
+	pSMB->ParameterOffset = cpu_to_le16((int) &(pSMB->InformationLevel)
+					    - (int) pSMB->hdr.Protocol);
 	pSMB->DataCount = 0;
 	pSMB->DataOffset = 0;
 	pSMB->SetupCount = 1;
@@ -1599,20 +1662,27 @@ int CIFSSMBQFSInfo(const int xid, const struct cifsTconInfo *tcon,
 	if (rc) {
 		cERROR(1, ("\nSend error in QFSInfo = %d\n", rc));
 	} else {		/* decode response */
-        pSMBr->DataOffset = le16_to_cpu(pSMBr->DataOffset);
+		pSMBr->DataOffset = le16_to_cpu(pSMBr->DataOffset);
 		cFYI(1,
 		     ("\nDecoding qfsinfo response.  BCC: %d  Offset %d\n",
 		      pSMBr->ByteCount, pSMBr->DataOffset));
 		if ((pSMBr->ByteCount < 24) || (pSMBr->DataOffset > 512))	/* BB also check enough total bytes returned */
-			rc = EIO;	/* bad smb */
+			rc = -EIO;	/* bad smb */
 		else {
 			response_data =
 			    (FILE_SYSTEM_INFO
 			     *) (((char *) &pSMBr->hdr.Protocol) +
 				 pSMBr->DataOffset);
-			FSData->f_bsize = le32_to_cpu(response_data->BytesPerSector) * le32_to_cpu(response_data->SectorsPerAllocationUnit);
-			FSData->f_blocks = le64_to_cpu(response_data->TotalAllocationUnits);
-			FSData->f_bfree = FSData->f_bavail = le64_to_cpu(response_data->FreeAllocationUnits);
+			FSData->f_bsize =
+			    le32_to_cpu(response_data->BytesPerSector) *
+			    le32_to_cpu(response_data->
+					SectorsPerAllocationUnit);
+			FSData->f_blocks =
+			    le64_to_cpu(response_data->
+					TotalAllocationUnits);
+			FSData->f_bfree = FSData->f_bavail =
+			    le64_to_cpu(response_data->
+					FreeAllocationUnits);
 			cFYI(1,
 			     ("\nBlocks: %ld  Free: %ld Block size %ld\n",
 			      FSData->f_blocks, FSData->f_bfree,
@@ -1651,11 +1721,11 @@ int CIFSSMBQFSAttributeInfo(int xid, struct cifsTconInfo *tcon,
 	pSMB->Flags = 0;
 	pSMB->Timeout = 0;
 	pSMB->Reserved2 = 0;
-    pSMB->ByteCount = pSMB->TotalParameterCount + 1 /* pad */ ;
+	pSMB->ByteCount = pSMB->TotalParameterCount + 1 /* pad */ ;
 	pSMB->TotalParameterCount = cpu_to_le16(pSMB->TotalParameterCount);
 	pSMB->ParameterCount = pSMB->TotalParameterCount;
-	pSMB->ParameterOffset = cpu_to_le16(
-	    (int) &(pSMB->InformationLevel) - (int) pSMB->hdr.Protocol);
+	pSMB->ParameterOffset = cpu_to_le16((int) &(pSMB->InformationLevel)
+					    - (int) pSMB->hdr.Protocol);
 	pSMB->DataCount = 0;
 	pSMB->DataOffset = 0;
 	pSMB->SetupCount = 1;
@@ -1670,9 +1740,9 @@ int CIFSSMBQFSAttributeInfo(int xid, struct cifsTconInfo *tcon,
 	if (rc) {
 		cERROR(1, ("\nSend error in QFSAttributeInfo = %d\n", rc));
 	} else {		/* decode response */
-        pSMBr->DataOffset = le16_to_cpu(pSMBr->DataOffset);
+		pSMBr->DataOffset = le16_to_cpu(pSMBr->DataOffset);
 		if ((pSMBr->ByteCount < 13) || (pSMBr->DataOffset > 512)) {	/* BB also check enough bytes returned */
-			rc = EIO;	/* bad smb */
+			rc = -EIO;	/* bad smb */
 		} else {
 			response_data =
 			    (FILE_SYSTEM_ATTRIBUTE_INFO
@@ -1718,7 +1788,9 @@ int CIFSSMBQFSDeviceInfo(int xid, struct cifsTconInfo *tcon,
 	pSMB->ByteCount = pSMB->TotalParameterCount + 1 /* pad */ ;
 	pSMB->TotalParameterCount = cpu_to_le16(pSMB->TotalParameterCount);
 	pSMB->ParameterCount = pSMB->TotalParameterCount;
-	pSMB->ParameterOffset = cpu_to_le16((int) &(pSMB->InformationLevel) - (int) pSMB->hdr.Protocol);
+	pSMB->ParameterOffset =
+	    cpu_to_le16((int) &(pSMB->InformationLevel) -
+			(int) pSMB->hdr.Protocol);
 	pSMB->DataCount = 0;
 	pSMB->DataOffset = 0;
 	pSMB->SetupCount = 1;
@@ -1733,9 +1805,9 @@ int CIFSSMBQFSDeviceInfo(int xid, struct cifsTconInfo *tcon,
 	if (rc) {
 		cERROR(1, ("\nSend error in QFSDeviceInfo = %d\n", rc));
 	} else {		/* decode response */
-        pSMBr->DataOffset = le16_to_cpu(pSMBr->DataOffset);
+		pSMBr->DataOffset = le16_to_cpu(pSMBr->DataOffset);
 		if ((pSMBr->ByteCount < sizeof(FILE_SYSTEM_DEVICE_INFO)) || (pSMBr->DataOffset > 512))	/* BB also check enough bytes returned */
-			rc = EIO;	/* bad smb */
+			rc = -EIO;	/* bad smb */
 		else {
 			response_data =
 			    (FILE_SYSTEM_DEVICE_INFO
@@ -1770,7 +1842,7 @@ int CIFSSMBQFSUnixInfo(int xid, struct cifsTconInfo *tcon,
 
 	pSMB->ParameterCount = 2;	/* level */
 	pSMB->TotalDataCount = 0;
-    pSMB->DataCount = 0;
+	pSMB->DataCount = 0;
 	pSMB->DataOffset = 0;
 	pSMB->MaxParameterCount = cpu_to_le16(2);
 	pSMB->MaxDataCount = cpu_to_le16(100);	/* BB find exact max SMB PDU from sess structure BB */
@@ -1782,7 +1854,9 @@ int CIFSSMBQFSUnixInfo(int xid, struct cifsTconInfo *tcon,
 	pSMB->ByteCount = pSMB->ParameterCount + 1 /* pad */ ;
 	pSMB->ParameterCount = cpu_to_le16(pSMB->ParameterCount);
 	pSMB->TotalParameterCount = pSMB->ParameterCount;
-	pSMB->ParameterOffset = cpu_to_le16((int) &(pSMB->InformationLevel) - (int) pSMB->hdr.Protocol);
+	pSMB->ParameterOffset =
+	    cpu_to_le16((int) &(pSMB->InformationLevel) -
+			(int) pSMB->hdr.Protocol);
 	pSMB->SetupCount = 1;
 	pSMB->Reserved3 = 0;
 	pSMB->SubCommand = cpu_to_le16(TRANS2_QUERY_FS_INFORMATION);
@@ -1795,9 +1869,9 @@ int CIFSSMBQFSUnixInfo(int xid, struct cifsTconInfo *tcon,
 	if (rc) {
 		cERROR(1, ("\nSend error in QFSUnixInfo = %d\n", rc));
 	} else {		/* decode response */
-        pSMBr->DataOffset = cpu_to_le16(pSMBr->DataOffset);
+		pSMBr->DataOffset = cpu_to_le16(pSMBr->DataOffset);
 		if ((pSMBr->ByteCount < 13) || (pSMBr->DataOffset > 512)) {	/* BB also check enough bytes returned */
-			rc = EIO;	/* bad smb */
+			rc = -EIO;	/* bad smb */
 		} else {
 			response_data =
 			    (FILE_SYSTEM_UNIX_INFO
@@ -1828,7 +1902,6 @@ int CIFSSMBSetEOF(int xid, struct cifsTconInfo *tcon, char *fileName,
 
 	cFYI(1, ("\nIn SetEOF"));
 
-
 	rc = smb_init(SMB_COM_TRANSACTION2, 15, tcon, (void **) &pSMB,
 		      (void **) &pSMBr);
 	if (rc)
@@ -1856,26 +1929,29 @@ int CIFSSMBSetEOF(int xid, struct cifsTconInfo *tcon, char *fileName,
 	pSMB->Flags = 0;
 	pSMB->Timeout = 0;
 	pSMB->Reserved2 = 0;
-	pSMB->ParameterOffset = (int) &(pSMB->InformationLevel) - (int) pSMB->hdr.Protocol;
-	pSMB->DataOffset = pSMB->ParameterOffset + pSMB->TotalParameterCount;
+	pSMB->ParameterOffset =
+	    (int) &(pSMB->InformationLevel) - (int) pSMB->hdr.Protocol;
+	pSMB->DataOffset = pSMB->ParameterOffset + pSMB->ParameterCount;
 	parm_data =
 	    (FILE_END_OF_FILE_INFO *) (((char *) &pSMB->hdr.Protocol) +
 				       pSMB->DataOffset);
-    pSMB->ParameterOffset = cpu_to_le16(pSMB->ParameterOffset);
-    pSMB->DataOffset = cpu_to_le16(pSMB->DataOffset);
+	pSMB->ParameterOffset = cpu_to_le16(pSMB->ParameterOffset);
+	pSMB->DataOffset = cpu_to_le16(pSMB->DataOffset);
 	pSMB->SetupCount = 1;
 	pSMB->Reserved3 = 0;
 	pSMB->SubCommand = cpu_to_le16(TRANS2_SET_PATH_INFORMATION);
 	pSMB->ByteCount =
 	    3 /* pad */  + pSMB->ParameterCount + pSMB->DataCount;
-    pSMB->DataCount = cpu_to_le16(pSMB->DataCount);
-    pSMB->TotalDataCount = pSMB->TotalDataCount;
-    pSMB->ParameterCount = cpu_to_le16(pSMB->ParameterCount);
+	pSMB->DataCount = cpu_to_le16(pSMB->DataCount);
+	pSMB->TotalDataCount = pSMB->DataCount;
+	pSMB->ParameterCount = cpu_to_le16(pSMB->ParameterCount);
 	pSMB->TotalParameterCount = pSMB->ParameterCount;
 	if (tcon->ses->capabilities & CAP_INFOLEVEL_PASSTHRU)
-		pSMB->InformationLevel = cpu_to_le16(SMB_SET_FILE_END_OF_FILE_INFO2);
+		pSMB->InformationLevel =
+		    cpu_to_le16(SMB_SET_FILE_END_OF_FILE_INFO2);
 	else
-		pSMB->InformationLevel = cpu_to_le16(SMB_SET_FILE_END_OF_FILE_INFO);
+		pSMB->InformationLevel =
+		    cpu_to_le16(SMB_SET_FILE_END_OF_FILE_INFO);
 	pSMB->Reserved4 = 0;
 	pSMB->hdr.smb_buf_length += pSMB->ByteCount;
 	parm_data->FileSize = cpu_to_le64(size);
@@ -1934,8 +2010,7 @@ int CIFSSMBSetAllocationSize(int xid, struct cifsTconInfo *tcon,
 	pSMB->Reserved2 = 0;
 	pSMB->ParameterOffset =
 	    (int) &(pSMB->InformationLevel) - (int) pSMB->hdr.Protocol;
-	pSMB->DataOffset =
-	    pSMB->ParameterOffset + pSMB->TotalParameterCount;
+	pSMB->DataOffset = pSMB->ParameterOffset + pSMB->ParameterCount;
 	parm_data =
 	    (FILE_END_OF_FILE_INFO *) (((char *) &pSMB->hdr.Protocol) +
 				       pSMB->DataOffset);
@@ -1950,10 +2025,12 @@ int CIFSSMBSetAllocationSize(int xid, struct cifsTconInfo *tcon,
 	pSMB->TotalParameterCount = pSMB->ParameterCount;
 	pSMB->DataOffset = cpu_to_le16(pSMB->DataOffset);
 	pSMB->ParameterOffset = cpu_to_le16(pSMB->ParameterOffset);
-    if (tcon->ses->capabilities & CAP_INFOLEVEL_PASSTHRU)
-		pSMB->InformationLevel = cpu_to_le16(SMB_SET_FILE_ALLOCATION_INFO2);
+	if (tcon->ses->capabilities & CAP_INFOLEVEL_PASSTHRU)
+		pSMB->InformationLevel =
+		    cpu_to_le16(SMB_SET_FILE_ALLOCATION_INFO2);
 	else
-		pSMB->InformationLevel = cpu_to_le16(SMB_SET_FILE_ALLOCATION_INFO);
+		pSMB->InformationLevel =
+		    cpu_to_le16(SMB_SET_FILE_ALLOCATION_INFO);
 
 	pSMB->Reserved4 = 0;
 	pSMB->hdr.smb_buf_length += pSMB->ByteCount;
@@ -2021,9 +2098,9 @@ int CIFSSMBSetTimes(int xid, struct cifsTconInfo *tcon, char *fileName,
 	    (int) &(pSMB->InformationLevel) - (int) pSMB->hdr.Protocol;
 	pSMB->DataOffset = pSMB->ParameterOffset + pSMB->ParameterCount;
 	data_offset = (char *) (&pSMB->hdr.Protocol) + pSMB->DataOffset;
-    pSMB->ParameterOffset = cpu_to_le16(pSMB->ParameterOffset);
+	pSMB->ParameterOffset = cpu_to_le16(pSMB->ParameterOffset);
 	pSMB->DataOffset = cpu_to_le16(pSMB->DataOffset);
-    pSMB->SetupCount = 1;
+	pSMB->SetupCount = 1;
 	pSMB->Reserved3 = 0;
 	pSMB->SubCommand = cpu_to_le16(TRANS2_SET_PATH_INFORMATION);
 	pSMB->ByteCount =
@@ -2034,9 +2111,11 @@ int CIFSSMBSetTimes(int xid, struct cifsTconInfo *tcon, char *fileName,
 	pSMB->TotalDataCount = pSMB->DataCount;
 	pSMB->TotalParameterCount = pSMB->ParameterCount;
 	if (tcon->ses->capabilities & CAP_INFOLEVEL_PASSTHRU)
-		pSMB->InformationLevel = cpu_to_le16(SMB_SET_FILE_BASIC_INFO2);
+		pSMB->InformationLevel =
+		    cpu_to_le16(SMB_SET_FILE_BASIC_INFO2);
 	else
-		pSMB->InformationLevel = cpu_to_le16(SMB_SET_FILE_BASIC_INFO);
+		pSMB->InformationLevel =
+		    cpu_to_le16(SMB_SET_FILE_BASIC_INFO);
 	pSMB->Reserved4 = 0;
 	pSMB->hdr.smb_buf_length += pSMB->ByteCount;
 	memcpy(data_offset, data, sizeof(FILE_BASIC_INFO));
@@ -2102,8 +2181,8 @@ int CIFSSMBUnixSetPerms(const int xid, struct cifsTconInfo *tcon,
 	data_offset =
 	    (FILE_UNIX_BASIC_INFO *) ((char *) &pSMB->hdr.Protocol +
 				      pSMB->DataOffset);
-    pSMB->DataOffset = cpu_to_le16(pSMB->DataOffset);
-    pSMB->ParameterOffset = cpu_to_le16(pSMB->ParameterOffset);
+	pSMB->DataOffset = cpu_to_le16(pSMB->DataOffset);
+	pSMB->ParameterOffset = cpu_to_le16(pSMB->ParameterOffset);
 	pSMB->SetupCount = 1;
 	pSMB->Reserved3 = 0;
 	pSMB->SubCommand = cpu_to_le16(TRANS2_SET_PATH_INFORMATION);
