@@ -239,9 +239,8 @@ int cifs_lock(struct file *file, int cmd, struct file_lock *pfLock)
 		FreeXid(xid);
 		return -EBADF;
 	}
-
 #if (LINUX_VERSION_CODE < KERNEL_VERSION(2,4,9))
-	if(cmd == F_GETLK) {
+	if (cmd == F_GETLK) {
 #else
 	if (IS_GETLK(cmd)) {
 #endif
@@ -301,8 +300,8 @@ ssize_t cifs_write(struct file * file, const char *write_data,
 	pTcon = cifs_sb->tcon;
 
 	/*cFYI(1,
-	     (" write %d bytes to offset %lld of %s \n", write_size,
-	      *poffset, file->f_dentry->d_name.name)); */
+	   (" write %d bytes to offset %lld of %s \n", write_size,
+	   *poffset, file->f_dentry->d_name.name)); */
 
 	if (file->private_data == NULL) {
 		FreeXid(xid);
@@ -334,12 +333,11 @@ ssize_t cifs_write(struct file * file, const char *write_data,
 			*poffset += bytes_written;
 		long_op = FALSE;	/* subsequent writes should be fast - 15 seconds is plenty of time */
 	}
-	file->f_dentry->d_inode->i_ctime =
-	    file->f_dentry->d_inode->i_mtime = CURRENT_TIME;  /* BB is this right? */
-    if(bytes_written > 0) {
-        if (*poffset > file->f_dentry->d_inode->i_size)
-            file->f_dentry->d_inode->i_size = *poffset;
-    }
+	file->f_dentry->d_inode->i_ctime = file->f_dentry->d_inode->i_mtime = CURRENT_TIME;	/* BB is this right? */
+	if (bytes_written > 0) {
+		if (*poffset > file->f_dentry->d_inode->i_size)
+			file->f_dentry->d_inode->i_size = *poffset;
+	}
 	mark_inode_dirty_sync(file->f_dentry->d_inode);
 	return total_written;
 }
@@ -402,17 +400,21 @@ void fill_in_inode(struct inode *tmp_inode,
 {
 	struct cifsInodeInfo *cifsInfo =
 	    (struct cifsInodeInfo *) &(tmp_inode->u);
-    pfindData->ExtFileAttributes = le32_to_cpu(pfindData->ExtFileAttributes);
-    pfindData->AllocationSize = le64_to_cpu(pfindData->AllocationSize);
-    pfindData->EndOfFile = le64_to_cpu(pfindData->EndOfFile);
+	pfindData->ExtFileAttributes =
+	    le32_to_cpu(pfindData->ExtFileAttributes);
+	pfindData->AllocationSize = le64_to_cpu(pfindData->AllocationSize);
+	pfindData->EndOfFile = le64_to_cpu(pfindData->EndOfFile);
 	cifsInfo->cifsAttrs = pfindData->ExtFileAttributes;
 	cifsInfo->time = jiffies;
 	atomic_inc(&cifsInfo->inUse);	/* inc on every refresh of inode info */
 
 	/* Linux can not store file creation time unfortunately so we ignore it */
-	tmp_inode->i_atime = le64_to_cpu(cifs_NTtimeToUnix(pfindData->LastAccessTime));
-	tmp_inode->i_mtime = le64_to_cpu(cifs_NTtimeToUnix(pfindData->LastWriteTime));
-	tmp_inode->i_ctime = le64_to_cpu(cifs_NTtimeToUnix(pfindData->ChangeTime));
+	tmp_inode->i_atime =
+	    le64_to_cpu(cifs_NTtimeToUnix(pfindData->LastAccessTime));
+	tmp_inode->i_mtime =
+	    le64_to_cpu(cifs_NTtimeToUnix(pfindData->LastWriteTime));
+	tmp_inode->i_ctime =
+	    le64_to_cpu(cifs_NTtimeToUnix(pfindData->ChangeTime));
 	/* should we treat the dos attribute of read-only as read-only mode bit e.g. 555 */
 	tmp_inode->i_mode = S_IALLUGO & ~(S_ISUID | S_IXGRP);	/* 2767 perms - indicate mandatory locking */
 	cFYI(0,
@@ -460,6 +462,7 @@ void fill_in_inode(struct inode *tmp_inode,
 				   kdev_t_to_nr(tmp_inode->i_rdev));
 	}
 }
+
 /* BB make endian neutral */
 void unix_fill_in_inode(struct inode *tmp_inode,
 			FILE_UNIX_INFO * pfindData, int *pobject_type)
@@ -469,18 +472,20 @@ void unix_fill_in_inode(struct inode *tmp_inode,
 	cifsInfo->time = jiffies;
 	atomic_inc(&cifsInfo->inUse);
 
-	tmp_inode->i_atime = le64_to_cpu(cifs_NTtimeToUnix(pfindData->LastAccessTime));
-	tmp_inode->i_mtime = le64_to_cpu(
-	    cifs_NTtimeToUnix(pfindData->LastModificationTime));
-	tmp_inode->i_ctime = le64_to_cpu(
-	    cifs_NTtimeToUnix(pfindData->LastStatusChange));
+	tmp_inode->i_atime =
+	    le64_to_cpu(cifs_NTtimeToUnix(pfindData->LastAccessTime));
+	tmp_inode->i_mtime =
+	    le64_to_cpu(cifs_NTtimeToUnix
+			(pfindData->LastModificationTime));
+	tmp_inode->i_ctime =
+	    le64_to_cpu(cifs_NTtimeToUnix(pfindData->LastStatusChange));
 
 	/* tmp_inode->i_mtime =
 	   cifs_NTtimeToUnix(pfindData->LastModificationTime);
 	   tmp_inode->i_ctime =
 	   cifs_NTtimeToUnix(pfindData->LastStatusChange); */
 	tmp_inode->i_mode = le64_to_cpu(pfindData->Permissions);
-    pfindData->Type = le32_to_cpu(pfindData->Type);
+	pfindData->Type = le32_to_cpu(pfindData->Type);
 	if (pfindData->Type == UNIX_FILE) {
 		*pobject_type = DT_REG;
 		tmp_inode->i_mode |= S_IFREG;
@@ -508,8 +513,8 @@ void unix_fill_in_inode(struct inode *tmp_inode,
 	tmp_inode->i_gid = le64_to_cpu(pfindData->Gid);
 	tmp_inode->i_nlink = le64_to_cpu(pfindData->Nlinks);
 
-    pfindData->NumOfBytes = le64_to_cpu(pfindData->NumOfBytes);
-    pfindData->EndOfFile = le64_to_cpu(pfindData->EndOfFile);
+	pfindData->NumOfBytes = le64_to_cpu(pfindData->NumOfBytes);
+	pfindData->EndOfFile = le64_to_cpu(pfindData->EndOfFile);
 	tmp_inode->i_size = pfindData->EndOfFile;
 	tmp_inode->i_blocks =
 	    do_div(pfindData->NumOfBytes, tmp_inode->i_blksize);
@@ -689,9 +694,11 @@ int cifs_readdir(struct file *file, void *direntry, filldir_t filldir)
 
 			renew_parental_timestamps(file->f_dentry);
 
-			for (i = 2; i < findParms.SearchCount + 2; i++) {                
+			for (i = 2; i < findParms.SearchCount + 2; i++) {
 				if (UnixSearch == FALSE) {
-                    pfindData->FileNameLength = le32_to_cpu(pfindData->FileNameLength);                   
+					pfindData->FileNameLength =
+					    le32_to_cpu(pfindData->
+							FileNameLength);
 					if (Unicode == TRUE)
 						pfindData->FileNameLength =
 						    cifs_strfromUCS_le
@@ -719,7 +726,7 @@ int cifs_readdir(struct file *file, void *direntry, filldir_t filldir)
 					}
 				} else {	/* UnixSearch */
 					pfindDataUnix =
-					    (FILE_UNIX_INFO *) pfindData;                  
+					    (FILE_UNIX_INFO *) pfindData;
 					if (Unicode == TRUE)
 						qstring.len =
 						    cifs_strfromUCS_le
@@ -787,8 +794,10 @@ int cifs_readdir(struct file *file, void *direntry, filldir_t filldir)
 			if ((rc == 0) && (findNextParms.SearchCount != 0)) {
 				for (i = 0; i < findNextParms.SearchCount;
 				     i++) {
-                    pfindData->FileNameLength = le32_to_cpu(pfindData->FileNameLength); 
-                    if (UnixSearch == FALSE) {
+					pfindData->FileNameLength =
+					    le32_to_cpu(pfindData->
+							FileNameLength);
+					if (UnixSearch == FALSE) {
 						if (Unicode == TRUE)
 							pfindData->
 							    FileNameLength
