@@ -96,14 +96,17 @@ int cifs_get_inode_info_unix(struct inode **pinode,
 		cFYI(1, (" New time %ld ", cifsInfo->time));
 		atomic_inc(&cifsInfo->inUse);	/* inc on every refresh of inode */
 
-		inode->i_atime = le64_to_cpu(
-		    cifs_NTtimeToUnix(findData.LastAccessTime));
-		inode->i_mtime = le64_to_cpu(
-		    cifs_NTtimeToUnix(findData.LastModificationTime));
-		inode->i_ctime = le64_to_cpu(
-		    cifs_NTtimeToUnix(findData.LastStatusChange));
+		inode->i_atime =
+		    le64_to_cpu(cifs_NTtimeToUnix
+				(findData.LastAccessTime));
+		inode->i_mtime =
+		    le64_to_cpu(cifs_NTtimeToUnix
+				(findData.LastModificationTime));
+		inode->i_ctime =
+		    le64_to_cpu(cifs_NTtimeToUnix
+				(findData.LastStatusChange));
 		inode->i_mode = le64_to_cpu(findData.Permissions);
-        findData.Type = le32_to_cpu(findData.Type);
+		findData.Type = le32_to_cpu(findData.Type);
 		if (findData.Type == UNIX_FILE) {
 			inode->i_mode |= S_IFREG;
 		} else if (findData.Type == UNIX_SYMLINK) {
@@ -122,8 +125,8 @@ int cifs_get_inode_info_unix(struct inode **pinode,
 		inode->i_uid = le64_to_cpu(findData.Uid);
 		inode->i_gid = le64_to_cpu(findData.Gid);
 		inode->i_nlink = le64_to_cpu(findData.Nlinks);
-        findData.NumOfBytes = le64_to_cpu(findData.NumOfBytes);
-        findData.EndOfFile = le64_to_cpu(findData.EndOfFile);
+		findData.NumOfBytes = le64_to_cpu(findData.NumOfBytes);
+		findData.EndOfFile = le64_to_cpu(findData.EndOfFile);
 		inode->i_size = findData.EndOfFile;
 		inode->i_blksize =
 		    (pTcon->ses->maxBuf - MAX_CIFS_HDR_SIZE) & 0xFFFFFE00;
@@ -219,8 +222,8 @@ int cifs_get_inode_info(struct inode **pinode,
 
 		inode = *pinode;
 		cifsInfo = (struct cifsInodeInfo *) &(inode->u);
-        findData.Attributes = le32_to_cpu(findData.Attributes);
-        cifsInfo->cifsAttrs = findData.Attributes;
+		findData.Attributes = le32_to_cpu(findData.Attributes);
+		cifsInfo->cifsAttrs = findData.Attributes;
 		cFYI(1, ("\nOld time %ld ", cifsInfo->time));
 		cifsInfo->time = jiffies;
 		cFYI(1, (" New time %ld ", cifsInfo->time));
@@ -229,9 +232,13 @@ int cifs_get_inode_info(struct inode **pinode,
 		inode->i_blksize =
 		    (pTcon->ses->maxBuf - MAX_CIFS_HDR_SIZE) & 0xFFFFFE00;
 		/* Linux can not store file creation time unfortunately so we ignore it */
-		inode->i_atime = cifs_NTtimeToUnix(le64_to_cpu(findData.LastAccessTime));
-		inode->i_mtime = cifs_NTtimeToUnix(le64_to_cpu(findData.LastWriteTime));
-		inode->i_ctime = cifs_NTtimeToUnix(le64_to_cpu(findData.ChangeTime));
+		inode->i_atime =
+		    cifs_NTtimeToUnix(le64_to_cpu
+				      (findData.LastAccessTime));
+		inode->i_mtime =
+		    cifs_NTtimeToUnix(le64_to_cpu(findData.LastWriteTime));
+		inode->i_ctime =
+		    cifs_NTtimeToUnix(le64_to_cpu(findData.ChangeTime));
 /* inode->i_mode = S_IRWXUGO;  *//* 777 perms */
 		/* should we treat the dos attribute of read-only as read-only mode bit e.g. 555 */
 		inode->i_mode = S_IALLUGO & ~(S_ISUID | S_IXGRP);	/* 2767 perms indicate mandatory locking - will override for dirs later */
@@ -248,8 +255,10 @@ int cifs_get_inode_info(struct inode **pinode,
 			/* BB add code here - validate if device or weird share type or device type? BB */
 		}
 		inode->i_size = le64_to_cpu(findData.EndOfFile);
-        findData.AllocationSize = le64_to_cpu(findData.AllocationSize);
-		inode->i_blocks = do_div(findData.AllocationSize, inode->i_blksize);
+		findData.AllocationSize =
+		    le64_to_cpu(findData.AllocationSize);
+		inode->i_blocks =
+		    do_div(findData.AllocationSize, inode->i_blksize);
 		cFYI(1,
 		     ("\n Size %ld and blocks %ld ",
 		      (unsigned long) inode->i_size, inode->i_blocks));
@@ -298,7 +307,7 @@ int cifs_unlink(struct inode *inode, struct dentry *direntry)
 	struct cifs_sb_info *cifs_sb;
 	struct cifsTconInfo *pTcon;
 	char *full_path = NULL;
-    struct cifsInodeInfo * cifsInode;
+	struct cifsInodeInfo *cifsInode;
 
 
 	cFYI(1, ("\n cifs_unlink, inode = 0x%p with ", inode));
@@ -308,20 +317,21 @@ int cifs_unlink(struct inode *inode, struct dentry *direntry)
 	cifs_sb = (struct cifs_sb_info *) (&(inode->i_sb->u));
 	pTcon = cifs_sb->tcon;
 
-    /* BB Should we close the file if it is already open from our client? */
+	/* BB Should we close the file if it is already open from our client? */
 
 	full_path = build_path_from_dentry(direntry);
 
 	rc = CIFSSMBDelFile(xid, pTcon, full_path, cifs_sb->local_nls);
 
-    if(!rc) {          
-        direntry->d_inode->i_nlink--;
-    }
-    cifsInode = (struct cifsInodeInfo *)&direntry->d_inode->u;
-    cifsInode->time = 0; /* will force revalidate to go get info when needed */
-    direntry->d_inode->i_ctime = inode->i_ctime = inode->i_mtime = CURRENT_TIME;
-    cifsInode = (struct cifsInodeInfo *)&inode->u;
-    cifsInode->time = 0; /* force revalidate of dir as well */
+	if (!rc) {
+		direntry->d_inode->i_nlink--;
+	}
+	cifsInode = (struct cifsInodeInfo *) &direntry->d_inode->u;
+	cifsInode->time = 0;	/* will force revalidate to go get info when needed */
+	direntry->d_inode->i_ctime = inode->i_ctime = inode->i_mtime =
+	    CURRENT_TIME;
+	cifsInode = (struct cifsInodeInfo *) &inode->u;
+	cifsInode->time = 0;	/* force revalidate of dir as well */
 
 	if (full_path)
 		kfree(full_path);
@@ -337,8 +347,8 @@ int cifs_mkdir(struct inode *inode, struct dentry *direntry, int mode)
 	struct cifsTconInfo *pTcon;
 	char *full_path = NULL;
 	struct inode *newinode = NULL;
-    	
-    cFYI(1, ("In cifs_mkdir, inode = 0x%p\n", inode));
+
+	cFYI(1, ("In cifs_mkdir, inode = 0x%p\n", inode));
 
 	xid = GetXid();
 
@@ -351,7 +361,7 @@ int cifs_mkdir(struct inode *inode, struct dentry *direntry, int mode)
 	if (rc) {
 		cFYI(1, ("\ncifs_mkdir returned 0x%x ", rc));
 	} else {
-        inode->i_nlink++;
+		inode->i_nlink++;
 		if (pTcon->ses->capabilities & CAP_UNIX)
 			rc = cifs_get_inode_info_unix(&newinode, full_path,
 						      inode->i_sb);
@@ -359,9 +369,10 @@ int cifs_mkdir(struct inode *inode, struct dentry *direntry, int mode)
 			rc = cifs_get_inode_info(&newinode, full_path,
 						 inode->i_sb);
 
+		direntry->d_op = &cifs_dentry_ops;
 		d_instantiate(direntry, newinode);
-        direntry->d_inode->i_nlink = 2;	
-    }
+		direntry->d_inode->i_nlink = 2;
+	}
 	if (full_path)
 		kfree(full_path);
 	FreeXid(xid);
@@ -376,7 +387,7 @@ int cifs_rmdir(struct inode *inode, struct dentry *direntry)
 	struct cifs_sb_info *cifs_sb;
 	struct cifsTconInfo *pTcon;
 	char *full_path = NULL;
-    struct cifsInodeInfo * cifsInode;
+	struct cifsInodeInfo *cifsInode;
 
 	cFYI(1, ("\nn cifs_rmdir, inode = 0x%p with ", inode));
 
@@ -389,15 +400,16 @@ int cifs_rmdir(struct inode *inode, struct dentry *direntry)
 
 	rc = CIFSSMBRmDir(xid, pTcon, full_path, cifs_sb->local_nls);
 
-    if(!rc){
-        inode->i_nlink--;
-        direntry->d_inode->i_size = 0;
-        direntry->d_inode->i_nlink = 0;
-    }
+	if (!rc) {
+		inode->i_nlink--;
+		direntry->d_inode->i_size = 0;
+		direntry->d_inode->i_nlink = 0;
+	}
 
-    cifsInode = (struct cifsInodeInfo *)&direntry->d_inode->u;
-    cifsInode->time = 0; /* will force revalidate to go get info when needed */
-    direntry->d_inode->i_ctime = inode->i_ctime = inode->i_mtime = CURRENT_TIME;
+	cifsInode = (struct cifsInodeInfo *) &direntry->d_inode->u;
+	cifsInode->time = 0;	/* will force revalidate to go get info when needed */
+	direntry->d_inode->i_ctime = inode->i_ctime = inode->i_mtime =
+	    CURRENT_TIME;
 
 	if (full_path)
 		kfree(full_path);
@@ -462,7 +474,8 @@ int cifs_revalidate(struct dentry *direntry)
 	cifsInode = (struct cifsInodeInfo *) &(direntry->d_inode->u);
 
 
-	if ((time_before(jiffies, cifsInode->time + HZ)) && (direntry->d_inode->i_nlink == 1)) {
+	if ((time_before(jiffies, cifsInode->time + HZ))
+	    && (direntry->d_inode->i_nlink == 1)) {
 		cFYI(1, (" Do not need to revalidate "));
 		if (full_path)
 			kfree(full_path);
@@ -613,8 +626,8 @@ int cifs_setattr(struct dentry *direntry, struct iattr *attrs)
 		rc = CIFSSMBSetTimes(xid, pTcon, full_path, &time_buf,
 				     cifs_sb->local_nls);
 	}
-    cifsInode = (struct cifsInodeInfo *) &(direntry->d_inode->u);
-    cifsInode->time = 0; /* will force revalidate to go get attributes when needed */
+	cifsInode = (struct cifsInodeInfo *) &(direntry->d_inode->u);
+	cifsInode->time = 0;	/* will force revalidate to go get attributes when needed */
 
 	if (full_path)
 		kfree(full_path);
