@@ -73,11 +73,11 @@ struct cifsSesInfo *sesInfoAlloc(void)
 
 void sesInfoFree(struct cifsSesInfo *buf_to_free)
 {
-    if(buf_to_free == NULL) {
-        cFYI(1,("\nNull buffer passed to sesInfoFree"));
-        return;
-    }
-     
+	if (buf_to_free == NULL) {
+		cFYI(1, ("\nNull buffer passed to sesInfoFree"));
+		return;
+	}
+
 	atomic_dec(&sesInfoAllocCount);
 	list_del(&buf_to_free->cifsSessionList);
 	if (buf_to_free->serverOS)
@@ -107,11 +107,11 @@ struct cifsTconInfo *tconInfoAlloc(void)
 
 void tconInfoFree(struct cifsTconInfo *buf_to_free)
 {
-    if(buf_to_free == NULL)  {
-        cFYI(1,("\nNull buffer passed to tconInfoFree"));
-        return;
-    }
-      
+	if (buf_to_free == NULL) {
+		cFYI(1, ("\nNull buffer passed to tconInfoFree"));
+		return;
+	}
+
 	atomic_dec(&tconInfoAllocCount);
 	list_del(&buf_to_free->cifsConnectionList);
 	if (buf_to_free->nativeFileSystem)
@@ -150,12 +150,11 @@ void buf_release(void *buf_to_free)
 {
 	/* BB release the memory if threshold exceeded else put back in pool */
 /*  kfree(buf_to_free); */
-    if(buf_to_free == NULL)
-    {
-        cFYI(1,("\nNull buffer passed to buf_release"));
-        return;
-    }
-    kfree(buf_to_free);
+	if (buf_to_free == NULL) {
+		cFYI(1, ("\nNull buffer passed to buf_release"));
+		return;
+	}
+	kfree(buf_to_free);
 	atomic_dec(&bufAllocCount);
 	return;
 }
@@ -219,7 +218,8 @@ int checkSMBhdr(struct smb_hdr *smb, __u16 mid)
 	if ((*(unsigned int *) smb->Protocol == cpu_to_le32(0x424d53ff)) && (smb->Flags & SMBFLG_RESPONSE) && (mid == smb->Mid)) {	/* BB add check for length of SMB */
 		return 0;
 	} else {
-		if (*(unsigned int *) smb->Protocol != cpu_to_le32(0x424d53ff))
+		if (*(unsigned int *) smb->Protocol !=
+		    cpu_to_le32(0x424d53ff))
 			cERROR(1,
 			       ("\n Bad protocol string signature header is %x ",
 				*(unsigned int *) smb->Protocol));
