@@ -76,8 +76,7 @@ struct mid_q_entry *AllocMidQEntry(struct smb_hdr *smb_buffer,
 void DeleteMidQEntry(struct mid_q_entry *midEntry)
 {
 	/* BB add spinlock to protect midq for each session BB */
-	if (midEntry->resp_buf)
-		kfree(midEntry->resp_buf);
+	buf_release(midEntry->resp_buf);
 	list_del(&midEntry->qhead);
 	kfree(midEntry);
 	atomic_dec(&midCount);
@@ -141,8 +140,6 @@ int SendReceive(const unsigned int xid, struct cifsSesInfo *ses,
 	midQ = AllocMidQEntry(in_buf, ses);
 	if (midQ == NULL)
 		return -EIO;	/* reconnect should be done, if possible, in AllocMidQEntry */
-	/* BB should we convert more fields to little endian here such as flags2 ? */
-	midQ->resp_buf = out_buf;	/* BB won't work - need to have buffers allocated by socket receiver thread */
 	if (in_buf->smb_buf_length > CIFS_MAX_MSGSIZE + MAX_CIFS_HDR_SIZE) {
 		cERROR(1,
 		       ("\nIllegal length, greater than maximum frame, %d ",
@@ -153,7 +150,7 @@ int SendReceive(const unsigned int xid, struct cifsSesInfo *ses,
 	rc = smb_send(ses->server->ssocket, in_buf, in_buf->smb_buf_length,
 		      (struct sockaddr *) &(ses->server->sockAddr));
 
-	cFYI(1, ("\ncifs smb_send rc %d", rc));
+	cFYI(1, ("\ncifs smb_send rc %d", rc));	/* BB remove */
 	/* BB add code to wait for response and copy to out_buf */
 	if (long_op > 1)	/* writes past end of file can take a looooooong time */
 		timeout = 300 * HZ;
@@ -165,17 +162,20 @@ int SendReceive(const unsigned int xid, struct cifsSesInfo *ses,
 	timeout =
 	    interruptible_sleep_on_timeout(&ses->server->response_q,
 					   timeout);
-	cFYI(1, (" with timeout %ld and Out_buf: %x  midQ->resp_buf: %x ",
-		 timeout, (int) out_buf, (int) midQ->resp_buf));
-	cFYI(1,
-	     ("and Length: %x\n",
-	      be32_to_cpu(midQ->resp_buf->smb_buf_length)));
+	cFYI(1, (" with timeout %ld and Out_buf: %p  midQ->resp_buf: %p ",
+		 timeout, out_buf, midQ->resp_buf));
 	if (signal_pending(current)) {
 		cERROR(1, (KERN_ERR "\nCIFS: caught signal"));
 		DeleteMidQEntry(midQ);
 		return -EINTR;
 	} else {
-		receive_len = be32_to_cpu(midQ->resp_buf->smb_buf_length);
+		if (midQ->resp_buf)
+			receive_len =
+			    be32_to_cpu(midQ->resp_buf->smb_buf_length);
+		else {
+			DeleteMidQEntry(midQ);
+			return -EIO;
+		}
 	}
 
 	if (timeout == 0) {
@@ -214,9 +214,12 @@ int SendReceive(const unsigned int xid, struct cifsSesInfo *ses,
 			/* BB special case reconnect tid and reconnect uid here? */
 			rc = map_smb_to_linux_error(out_buf);	/* BB watch endianness here BB */
 
-            /* convert ByteCount if necessary */
-            if(receive_len >= sizeof(struct smb_hdr) - 4 /* do not count RFC1001 header */ + (2 * out_buf->WordCount) + 2 /* bcc */)
-                BCC(out_buf) = le16_to_cpu(BCC(out_buf));
+			/* convert ByteCount if necessary */
+			if (receive_len >=
+			    sizeof(struct smb_hdr) -
+			    4 /* do not count RFC1001 header */  +
+			    (2 * out_buf->WordCount) + 2 /* bcc */ )
+				BCC(out_buf) = le16_to_cpu(BCC(out_buf));
 		} else
 			rc = -EIO;
 	}
